/**
 * 弹出等级评定插件
 * version 1.0.1
 */

(function($, document) {

	//创建 DOM
	$.dom = function(str) {
		if (typeof(str) !== 'string') {
			if ((str instanceof Array) || (str[0] && str.length)) {
				return [].slice.call(str);
			} else {
				return [str];
			}
		}
		if (!$.__create_dom_div__) {
			$.__create_dom_div__ = document.createElement('div');
		}
		$.__create_dom_div__.innerHTML = str;
		return [].slice.call($.__create_dom_div__.childNodes);
	};

	var panelBuffer = '<div class="mui-poprating">\
		<div class="mui-poprating-header">\
			<table width="100%">\
				<tr>\
					<td colspan="3" width="100%"><div class="mui-poprating-mini-title">title</div></td>\
				</tr>\
				<tr>\
					<td width="33%"><button class="mui-btn mui-poprating-btn-cancel">取消</button></td>\
					<td width="33%"><div class="mui-poprating-mini-scr"></div></td>\
					<td width="34%"><button class="mui-btn mui-btn-blue mui-poprating-btn-ok">确定</button></td>\
				</tr>\
			</table>\
		</div>\
		<div class="mui-poprating-body">\
		</div>\
	</div>';

	var pickerBuffer = '<div class="mui-picker">\
		<div class="mui-poprating-inner">\
			<table width="100%" height="100%">\
				<tr>\
					<td width="20%" height="100%" align="center"><button class="mui-btn mui-poprating-btn mui-poprating_a">A</button></td>\
					<td width="20%" align="center"><button class="mui-btn mui-poprating-btn mui-poprating_b">B</button></td>\
					<td width="20%" align="center"><button class="mui-btn mui-poprating-btn mui-poprating_c">C</button></td>\
					<td width="20%" align="center"><button class="mui-btn mui-poprating-btn mui-poprating_d">D</button></td>\
					<td width="20%" align="center"><button class="mui-btn mui-poprating-btn mui-poprating_e">E</button></td>\
				</tr>\
			</table>\
		</div>\
	</div>';

	//定义弹出键盘
	var popRating = $.PopRating = $.Class.extend({
		//构造函数
		init: function(options) {
			var self = this;
			self.options = options || {};
			
			self.mapper = {'A':1,'B':2,'C':3,'D':4,'E':5};
			
			self.options.buttons = self.options.buttons || ['取消', '确定'];
			self.panel = $.dom(panelBuffer)[0];
			document.body.appendChild(self.panel);
			self.miniTitle = self.panel.querySelector('.mui-poprating-mini-title');//mini标题
			self.ok = self.panel.querySelector('.mui-poprating-btn-ok');
			self.miniScr = self.panel.querySelector('.mui-poprating-mini-scr');//mini回显屏幕
			self.cancel = self.panel.querySelector('.mui-poprating-btn-cancel');
			self.body = self.panel.querySelector('.mui-poprating-body');
			
			self.mask = $.createMask();
			self.cancel.innerText = self.options.buttons[0];
			self.ok.innerText = self.options.buttons[1];
			self.miniScr.innerText = "";
			self.cancel.addEventListener('tap', function(event) {
				self.hide();
			}, false);
			self.ok.addEventListener('tap', function(event) {
				if (self.callback) {
					var rs = self.callback(self.getValue());
					if (rs !== false) {
						self.hide();
					}
				}
			}, false);
			
			self.mask[0].addEventListener('tap', function() {
				self.hide();
			}, false);
			self._createPicker();
			
			self.numBtnA = self.body.querySelector('.mui-poprating_a');
			self.numBtnB = self.body.querySelector('.mui-poprating_b');
			self.numBtnC = self.body.querySelector('.mui-poprating_c');
			self.numBtnD = self.body.querySelector('.mui-poprating_d');
			self.numBtnE = self.body.querySelector('.mui-poprating_e');
			
			self.numBtnA.addEventListener('tap', function(event){
				self.setData('A');
			});
			self.numBtnB.addEventListener('tap', function(event){
				self.setData('B');
			});
			self.numBtnC.addEventListener('tap', function(event){
				self.setData('C');
			});
			self.numBtnD.addEventListener('tap', function(event){
				self.setData('D');
			});
			self.numBtnE.addEventListener('tap', function(event){
				self.setData('E');
			});
		},
		_createPicker: function() {
			var self = this;
			var pickerElement = $.dom(pickerBuffer)[0];
			pickerElement.style.width = '100%';
			self.body.appendChild(pickerElement);
			pickerElement.addEventListener('change', function(event) {
				
			}, false);
		},
		//通过等级字符获得等级ID
		getLevelId: function(level) {
			var self = this;
			return self.mapper[level];
		},
		//通过等级ID获得等级字符
		getLevel: function(id) {
			if ((id < 1) || (id > 5)) 
				return "";
			return fromCharCode(0x64 + id);
		},
		//获取值
		getValue: function() {
			var self = this;
			return self.miniScr.innerText;
		},
		//添加标题
		setTitle: function(data) {
			var self = this;
			self.miniTitle.innerText = data;
		},
		//填充数据
		setData: function(data) {
			var self = this;
			var r = /^A|B|C|D|E$/; //仅匹配一个大写字母
			if (r.test(data)) {
				self.miniScr.innerText = data;
			}
		},
		//显示
		show: function(callback) {
			var self = this;
			self.callback = callback;
			self.mask.show();
			document.body.classList.add($.className('poppicker-active-for-page'));
			self.panel.classList.add($.className('active'));
			//处理物理返回键
			self.__back = $.back;
			$.back = function() {
				self.hide();
			};
		},
		//隐藏
		hide: function() {
			var self = this;
			if (self.disposed) return;
			self.panel.classList.remove($.className('active'));
			self.mask.close();
			document.body.classList.remove($.className('poppicker-active-for-page'));
			//处理物理返回键
			$.back=self.__back;
		},
		dispose: function() {
			var self = this;
			self.hide();
			setTimeout(function() {
				self.panel.parentNode.removeChild(self.panel);
				for (var name in self) {
					self[name] = null;
					delete self[name];
				};
				self.disposed = true;
			}, 300);
		}
	});

})(mui, document);